package ordering;

// this class provides an interface to an ordering system. It makes
// calls to native C methods which take care of accessing the real
// system.

public class Ordering extends Object
{
// transactionID is the transaction id returned by the C interface
// to the ordering system. Each call to the ordering system must
// be accompanied by the transaction ID.

	int transactionID;

// Create an instance of an Ordering object, which begins an ordering
// transaction.

	public Ordering(String customerId)
	throws OrderingException
	{
		transactionID = startTransaction(customerId);
	}

// Add a part to the current order

	public void orderPart(String partNumber, int quantity)
	throws OrderingException
	{
		orderPart(transactionID, partNumber, quantity);
	}

// remove a part from the current order

	public void removePart(String partNumber)
	throws OrderingException
	{
		removePart(transactionID, partNumber);
	}

// finish the order

	public void endTransaction()
	throws OrderingException
	{
		endTransaction(transactionID);
	}

// abort the order

	public void abortTransaction()
	throws OrderingException
	{
		abortTransaction(transactionID);
	}

// These methods are implemented in a local DLL

	protected native int startTransaction(String customerId)
		throws OrderingException;

	public native static String[] listParts();

	protected native void orderPart(int txnID, String partNumber,
		int quantity) throws OrderingException;

	protected native void removePart(int txnID, String partNumber)
		throws OrderingException;

	protected native void endTransaction(int txnID)
		throws OrderingException;

	protected native void abortTransaction(int txnID)
		throws OrderingException;
}
		
